@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-sidebar-embed.c,v 1.7 2005/01/28 22:30:29 chpe Exp $
+ * $Id: ephy-sidebar-embed.c,v 1.8 2005/03/07 19:11:08 jordim Exp $
  */
 
 #include "config.h"
@@ -142,7 +142,7 @@ popup_menu_at_coords (GtkMenu *menu,
 {
 	EphyEmbedEvent *event = (EphyEmbedEvent *) user_data;
 
-	ephy_embed_event_get_coords (event, x, y);
+	ephy_embed_event_get_coords (event, (guint*) x, (guint*) y);
 
 	*push_in = TRUE;
 }
